Skip to contents

This package bundles together routines that utilizes Praat, matlab or python to do the signal processing. The output of the original routines are then wrapped into a common interface that outputs an SSFF file or returns a wrassp compatible AsspDataObj object.

Author

Maintainer: Fredrik Nylén fredrik.nylen@umu.se (ORCID)

Authors: