Skip to contents

Writes an object of class AsspDataObj to a file given the meta information contained in the object.

Usage

write.AsspDataObj(dobj, file = attr(dobj, "filePath"))

Arguments

dobj

an object of class AsspDataObj

file

file name as a character string, defaults to the filePath attribute of the AsspDataObj

Author

Lasse Bombien