write.AsspDataObj to file
write.AsspDataObj.RdWrites an object of class AsspDataObj to a file given the meta information contained in the object.
Usage
write.AsspDataObj(dobj, file = attr(dobj, "filePath"))write.AsspDataObj.RdWrites an object of class AsspDataObj to a file given the meta information contained in the object.
write.AsspDataObj(dobj, file = attr(dobj, "filePath"))